@@ -1,4 +1,4 @@
-#     Copyright 2022, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -29,7 +29,7 @@ import sys
 
 from nuitka.build.DataComposerInterface import runDataComposer
 from nuitka.build.SconsUtils import getSconsReportValue, readSconsReport
-from nuitka.constants.Serialization import ConstantAccessor
+from nuitka.code_generation.ConstantCodes import addDistributionMetadataValue
 from nuitka.freezer.IncludedDataFiles import (
     addIncludedDataFilesFromFileOptions,
     addIncludedDataFilesFromPackageOptions,
@@ -69,10 +69,12 @@ from nuitka.PythonVersions import (
     python_version,
     python_version_str,
 )
+from nuitka.Serialization import ConstantAccessor
 from nuitka.Tracing import general, inclusion_logger
 from nuitka.tree import SyntaxErrors
 from nuitka.tree.ReformulationMultidist import createMultidistMainSourceCode
 from nuitka.utils import InstanceCounters
+from nuitka.utils.Distributions import getDistribution
 from nuitka.utils.Execution import (
     callProcess,
     withEnvironmentVarOverridden,
@@ -161,6 +163,17 @@ def _createMainModule():
 
     OutputDirectories.setMainModule(main_module)
 
+    for distribution_name in Options.getShallIncludeDistributionMetadata():
+        distribution = getDistribution(distribution_name)
+
+        if distribution is None:
+            general.sysexit(
+                "Error, could not find distribution '%s' for which metadata was asked to be included."
+                % distribution_name
+            )
+
+        addDistributionMetadataValue(distribution_name, distribution)
+
     # First remove old object files and old generated files, old binary or
     # module, and standalone mode program directory if any, they can only do
     # harm.
