@@ -1,4 +1,4 @@
-#     Copyright 2022, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -57,8 +57,13 @@ def printSeparator(level=0):
     print("    " * level, "*" * 10)
 
 
-def printLine(*what):
-    print(*what)
+def printLine(*what, **kwargs):
+    is_atty = sys.stdout.isatty()
+
+    if progress and is_atty:
+        progress.close()
+
+    print(*what, **kwargs)
 
 
 def printError(message):
