@@ -1,4 +1,4 @@
-#     Copyright 2022, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -35,6 +35,19 @@ def main():
 
     # Also high complexity.
     # pylint: disable=too-many-branches,too-many-locals,too-many-statements
+    if (
+        os.name == "nt"
+        and os.path.normcase(os.path.basename(sys.executable)) == "pythonw.exe"
+    ):
+        import ctypes
+
+        ctypes.windll.user32.MessageBoxW(
+            None,
+            "You have to use the 'python.exe' and not a 'pythonw.exe' to run Nuitka",
+            "Error",
+            0x1000,  # MB_SYSTEMMODAL
+        )
+        sys.exit(1)
 
     if "NUITKA_BINARY_NAME" in os.environ:
         sys.argv[0] = os.environ["NUITKA_BINARY_NAME"]
@@ -73,6 +86,10 @@ def main():
     if os.environ.get("PYTHONHASHSEED", "-1") != "0":
         needs_re_execution = True
 
+    # Avoid doing it when running in Visual Code.
+    if needs_re_execution and "debugpy" in sys.modules:
+        needs_re_execution = False
+
     # In case we need to re-execute.
     if needs_re_execution:
         from nuitka.utils.ReExecute import reExecuteNuitka  # isort:skip
