@@ -1,4 +1,4 @@
-#     Copyright 2021, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -21,18 +21,24 @@ Some of these come from built-ins, e.g. abs, some from syntax, and repr from bot
 """
 from nuitka import PythonOperators
 
+from .ChildrenHavingMixins import ChildHavingOperandMixin
 from .ConstantRefNodes import makeConstantRefNode
-from .ExpressionBases import ExpressionChildHavingBase
-from .shapes.BuiltinTypeShapes import tshape_bool, tshape_str
+from .ExpressionBases import ExpressionBase
+from .ExpressionShapeMixins import (
+    ExpressionBoolShapeExactMixin,
+    ExpressionStrOrUnicodeDerivedShapeMixin,
+)
 
 
-class ExpressionOperationUnaryBase(ExpressionChildHavingBase):
-    named_child = "operand"
+class ExpressionOperationUnaryBase(ChildHavingOperandMixin, ExpressionBase):
+    named_children = ("operand",)
 
     __slots__ = ("operator", "simulator")
 
     def __init__(self, operand, source_ref):
-        ExpressionChildHavingBase.__init__(self, value=operand, source_ref=source_ref)
+        ChildHavingOperandMixin.__init__(self, operand=operand)
+
+        ExpressionBase.__init__(self, source_ref)
 
     def getOperator(self):
         return self.operator
@@ -69,8 +75,10 @@ class ExpressionOperationUnaryBase(ExpressionChildHavingBase):
         return True
 
 
-class ExpressionOperationUnaryRepr(ExpressionOperationUnaryBase):
-    """ Python unary operator `x` and repr built-in. """
+class ExpressionOperationUnaryRepr(  # TODO: Not exact
+    ExpressionStrOrUnicodeDerivedShapeMixin, ExpressionOperationUnaryBase
+):
+    """Python unary operator `x` and repr built-in."""
 
     kind = "EXPRESSION_OPERATION_UNARY_REPR"
 
@@ -102,9 +110,6 @@ class ExpressionOperationUnaryRepr(ExpressionOperationUnaryBase):
             or self.subnode_operand.mayRaiseException(exception_type)
         )
 
-    def mayRaiseExceptionBool(self, exception_type):
-        return False
-
     def mayHaveSideEffects(self):
         operand = self.subnode_operand
 
@@ -113,14 +118,9 @@ class ExpressionOperationUnaryRepr(ExpressionOperationUnaryBase):
 
         return self.escape_desc is None or self.escape_desc.isControlFlowEscape()
 
-    @staticmethod
-    def getTypeShape():
-        # Even unicode gets decoded in Python2
-        return tshape_str
-
 
 class ExpressionOperationUnarySub(ExpressionOperationUnaryBase):
-    """ Python unary operator - """
+    """Python unary operator -"""
 
     kind = "EXPRESSION_OPERATION_UNARY_SUB"
 
@@ -136,7 +136,7 @@ class ExpressionOperationUnarySub(ExpressionOperationUnaryBase):
 
 
 class ExpressionOperationUnaryAdd(ExpressionOperationUnaryBase):
-    """ Python unary operator + """
+    """Python unary operator +"""
 
     kind = "EXPRESSION_OPERATION_UNARY_ADD"
 
@@ -152,7 +152,7 @@ class ExpressionOperationUnaryAdd(ExpressionOperationUnaryBase):
 
 
 class ExpressionOperationUnaryInvert(ExpressionOperationUnaryBase):
-    """ Python unary operator ~ """
+    """Python unary operator ~"""
 
     kind = "EXPRESSION_OPERATION_UNARY_INVERT"
 
@@ -167,7 +167,9 @@ class ExpressionOperationUnaryInvert(ExpressionOperationUnaryBase):
         )
 
 
-class ExpressionOperationNot(ExpressionOperationUnaryBase):
+class ExpressionOperationNot(
+    ExpressionBoolShapeExactMixin, ExpressionOperationUnaryBase
+):
     kind = "EXPRESSION_OPERATION_NOT"
 
     operator = "Not"
@@ -178,10 +180,6 @@ class ExpressionOperationNot(ExpressionOperationUnaryBase):
             self, operand=operand, source_ref=source_ref
         )
 
-    @staticmethod
-    def getTypeShape():
-        return tshape_bool
-
     def computeExpression(self, trace_collection):
         return self.subnode_operand.computeExpressionOperationNot(
             not_node=self, trace_collection=trace_collection
@@ -192,9 +190,6 @@ class ExpressionOperationNot(ExpressionOperationUnaryBase):
             exception_type
         ) or self.subnode_operand.mayRaiseExceptionBool(exception_type)
 
-    def mayRaiseExceptionBool(self, exception_type):
-        return self.subnode_operand.mayRaiseExceptionBool(exception_type)
-
     def getTruthValue(self):
         result = self.subnode_operand.getTruthValue()
 
