@@ -1,4 +1,4 @@
-#     Copyright 2022, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -44,6 +44,7 @@ from nuitka.nodes.shapes.StandardShapes import (
     tshape_uninitialized,
     tshape_unknown,
 )
+from nuitka.Tracing import my_print
 from nuitka.utils.InstanceCounters import (
     counted_del,
     counted_init,
@@ -88,6 +89,9 @@ class ValueTraceBase(object):
     def __repr__(self):
         return "<%s of %s>" % (self.__class__.__name__, self.owner.getCodeName())
 
+    def dump(self, indent):
+        my_print("%s%s %s:" % (indent, self.__class__.__name__, id(self)))
+
     def getOwner(self):
         return self.owner
 
@@ -183,6 +187,10 @@ class ValueTraceBase(object):
 
         return None
 
+    @staticmethod
+    def hasShapeListExact():
+        return False
+
     @staticmethod
     def hasShapeDictionaryExact():
         return False
@@ -199,6 +207,10 @@ class ValueTraceBase(object):
     def hasShapeTupleExact():
         return False
 
+    @staticmethod
+    def hasShapeBoolExact():
+        return False
+
     @staticmethod
     def getTruthValue():
         return None
@@ -233,6 +245,17 @@ class ValueTraceBase(object):
         """Node to use for iteration decisions."""
         return None
 
+    @staticmethod
+    def getDictInValue(key):
+        """Value to use for dict in decisions."""
+
+        # virtual method, pylint: disable=unused-argument
+        return None
+
+    @staticmethod
+    def inhibitsClassScopeForwardPropagation():
+        return True
+
 
 class ValueTraceUnassignedBase(ValueTraceBase):
     __slots__ = ()
@@ -276,8 +299,8 @@ class ValueTraceUninitialized(ValueTraceUnassignedBase):
     def isTraceThatNeedsEscape():
         return False
 
-    def dump(self, indent):
-        print("%s%s %s:" % (indent, self.__class__.__name__, id(self)))
+    def inhibitsClassScopeForwardPropagation(self):
+        return False
 
 
 class ValueTraceDeleted(ValueTraceUnassignedBase):
@@ -473,6 +496,16 @@ class ValueTraceEscaped(ValueTraceUnknown):
     def getAttributeNodeVeryTrusted(self):
         return self.previous.getAttributeNodeVeryTrusted()
 
+    # For escaped values, these do not have to forget their shape, the mutable ones
+    # and the only ones affected.
+    def hasShapeListExact(self):
+        trusted_node = self.previous.getAttributeNodeTrusted()
+        return trusted_node is not None and trusted_node.hasShapeListExact()
+
+    def hasShapeDictionaryExact(self):
+        trusted_node = self.previous.getAttributeNodeTrusted()
+        return trusted_node is not None and trusted_node.hasShapeDictionaryExact()
+
 
 class ValueTraceAssign(ValueTraceBase):
     __slots__ = ("assign_node",)
@@ -513,6 +546,9 @@ class ValueTraceAssign(ValueTraceBase):
     def getAssignNode(self):
         return self.assign_node
 
+    def hasShapeListExact(self):
+        return self.assign_node.subnode_source.hasShapeListExact()
+
     def hasShapeDictionaryExact(self):
         return self.assign_node.subnode_source.hasShapeDictionaryExact()
 
@@ -522,6 +558,9 @@ class ValueTraceAssign(ValueTraceBase):
     def hasShapeUnicodeExact(self):
         return self.assign_node.subnode_source.hasShapeUnicodeExact()
 
+    def hasShapeBoolExact(self):
+        return self.assign_node.subnode_source.hasShapeBoolExact()
+
     def getTruthValue(self):
         return self.assign_node.subnode_source.getTruthValue()
 
@@ -549,6 +588,13 @@ class ValueTraceAssign(ValueTraceBase):
     def getIterationSourceNode(self):
         return self.assign_node.subnode_source
 
+    def getDictInValue(self, key):
+        """Value to use for dict in decisions."""
+        return self.assign_node.subnode_source.getExpressionDictInConstant(key)
+
+    def inhibitsClassScopeForwardPropagation(self):
+        return self.assign_node.subnode_source.mayHaveSideEffects()
+
 
 class ValueTraceAssignUnescapable(ValueTraceAssign):
     @staticmethod
@@ -604,7 +650,7 @@ class ValueTraceMergeBase(ValueTraceBase):
         self.merge_usage_count += 1
 
     def dump(self, indent):
-        print("%s%s %s:" % (indent, self.__class__.__name__, id(self)))
+        ValueTraceBase.dump(self, indent)
 
         for trace in self.previous:
             trace.dump(indent + "  ")
@@ -708,6 +754,9 @@ class ValueTraceMerge(ValueTraceMergeBase):
 
         return True
 
+    def hasShapeListExact(self):
+        return all(previous.hasShapeListExact() for previous in self.previous)
+
     def hasShapeDictionaryExact(self):
         return all(previous.hasShapeDictionaryExact() for previous in self.previous)
 
