@@ -1,4 +1,4 @@
-#     Copyright 2022, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -23,7 +23,9 @@ that to be done and causing massive degradations.
 """
 
 import ast
+import os
 import re
+import sys
 
 from nuitka.containers.OrderedDicts import OrderedDict
 from nuitka.Errors import NuitkaForbiddenImportEncounter
@@ -33,6 +35,8 @@ from nuitka.utils.Yaml import getYamlPackageConfiguration
 
 # spell-checker: ignore dask,numba
 
+_mode_choices = ("error", "warning", "nofollow", "allow")
+
 
 class NuitkaPluginAntiBloat(NuitkaPluginBase):
     plugin_name = "anti-bloat"
@@ -88,7 +92,9 @@ class NuitkaPluginAntiBloat(NuitkaPluginBase):
             self.control_tags["use_setuptools"] = True
 
         if noinclude_pytest_mode != "allow":
+            self.handled_modules["_pytest"] = noinclude_pytest_mode
             self.handled_modules["pytest"] = noinclude_pytest_mode
+            self.handled_modules["py"] = noinclude_pytest_mode
             self.handled_modules["nose2"] = noinclude_pytest_mode
             self.handled_modules["nose"] = noinclude_pytest_mode
         else:
@@ -96,6 +102,7 @@ class NuitkaPluginAntiBloat(NuitkaPluginBase):
 
         if noinclude_unittest_mode != "allow":
             self.handled_modules["unittest"] = noinclude_unittest_mode
+            self.handled_modules["doctest"] = noinclude_unittest_mode
         else:
             self.control_tags["use_unittest"] = True
 
@@ -124,7 +131,7 @@ class NuitkaPluginAntiBloat(NuitkaPluginBase):
 
             module_name, mode = custom_choice.rsplit(":", 1)
 
-            if mode not in ("error", "warning", "nofollow", "allow", "bytecode"):
+            if mode not in _mode_choices and mode != "bytecode":
                 self.sysexit(
                     "Error, illegal mode given '%s' in '--noinclude-custom-mode=%s'"
                     % (mode, custom_choice)
@@ -132,6 +139,8 @@ class NuitkaPluginAntiBloat(NuitkaPluginBase):
 
             self.handled_modules[ModuleName(module_name)] = mode
 
+        self.warnings_given = set()
+
     def getCacheContributionValues(self, module_name):
         config = self.config.get(module_name, section="anti-bloat")
 
@@ -153,7 +162,7 @@ Annotate what changes are by the plugin done.""",
             "--noinclude-setuptools-mode",
             action="store",
             dest="noinclude_setuptools_mode",
-            choices=("error", "warning", "nofollow", "allow"),
+            choices=_mode_choices,
             default=None,
             help="""\
 What to do if a 'setuptools' or import is encountered. This package can be big with
@@ -164,7 +173,7 @@ dependencies, and should definitely be avoided. Also handles 'setuptools_scm'.""
             "--noinclude-pytest-mode",
             action="store",
             dest="noinclude_pytest_mode",
-            choices=("error", "warning", "nofollow", "allow"),
+            choices=_mode_choices,
             default=None,
             help="""\
 What to do if a 'pytest' import is encountered. This package can be big with
@@ -175,7 +184,7 @@ dependencies, and should definitely be avoided. Also handles 'nose' imports.""",
             "--noinclude-unittest-mode",
             action="store",
             dest="noinclude_unittest_mode",
-            choices=("error", "warning", "nofollow", "allow"),
+            choices=_mode_choices,
             default=None,
             help="""\
 What to do if a unittest import is encountered. This package can be big with
@@ -186,7 +195,7 @@ dependencies, and should definitely be avoided.""",
             "--noinclude-IPython-mode",
             action="store",
             dest="noinclude_ipython_mode",
-            choices=("error", "warning", "nofollow", "allow"),
+            choices=_mode_choices,
             default=None,
             help="""\
 What to do if a IPython import is encountered. This package can be big with
@@ -197,7 +206,7 @@ dependencies, and should definitely be avoided.""",
             "--noinclude-dask-mode",
             action="store",
             dest="noinclude_dask_mode",
-            choices=("error", "warning", "nofollow", "allow"),
+            choices=_mode_choices,
             default=None,
             help="""\
 What to do if a 'dask' import is encountered. This package can be big with
@@ -208,7 +217,7 @@ dependencies, and should definitely be avoided.""",
             "--noinclude-numba-mode",
             action="store",
             dest="noinclude_numba_mode",
-            choices=("error", "warning", "nofollow", "allow"),
+            choices=_mode_choices,
             default=None,
             help="""\
 What to do if a 'numba' import is encountered. This package can be big with
@@ -220,7 +229,7 @@ big with dependencies, and should definitely be avoided.""",
             "--noinclude-default-mode",
             action="store",
             dest="noinclude_default_mode",
-            choices=("error", "warning", "nofollow", "allow"),
+            choices=_mode_choices,
             default="warning",
             help="""\
 This actually provides the default "warning" value for above options, and
@@ -246,10 +255,12 @@ which can and should be a top level package and then one choice, "error",
         # To allow detection if it did anything.
         change_count = 0
 
-        context = {}
+        context = {"sys": sys, "os": os}
+
         context_code = anti_bloat_config.get("context", "")
         if type(context_code) in (tuple, list):
             context_code = "\n".join(context_code)
+        context["version"] = self.getPackageVersion
 
         # We trust the yaml files, pylint: disable=eval-used,exec-used
         context_ready = not bool(context_code)
@@ -272,6 +283,10 @@ which can and should be a top level package and then one choice, "error",
                         )
 
                     context_ready = True
+
+                if "__dirname__" in replace_code:
+                    context["__dirname__"] = self.locateModule(module_name)
+
                 try:
                     replace_dst = eval(replace_code, context)
                 except Exception as e:  # pylint: disable=broad-except
@@ -284,8 +299,8 @@ which can and should be a top level package and then one choice, "error",
 
             if type(replace_dst) is not str:
                 self.sysexit(
-                    "Error, expression needs to generate string, not %s"
-                    % type(replace_dst)
+                    "Error, expression code '%s' needs to generate string, not %s"
+                    % (replace_code, type(replace_dst))
                 )
 
             old = source_code
@@ -441,14 +456,40 @@ which can and should be a top level package and then one choice, "error",
                     body=body,
                 )
 
-    def onModuleRecursion(self, module_name, module_filename, module_kind):
+    def onModuleRecursion(
+        self, module_name, module_filename, module_kind, using_module, source_ref
+    ):
         for handled_module_name, mode in self.handled_modules.items():
             if module_name.hasNamespace(handled_module_name):
-                # Make sure the compilation aborts.
+                # Make sure the compilation aborts or warns if asked to
                 if mode == "error":
                     raise NuitkaForbiddenImportEncounter(module_name)
-                if mode == "warning":
-                    self.warning("Unwanted import of '%s' encountered." % module_name)
+                if mode == "warning" and (
+                    (
+                        using_module is None
+                        or not using_module.getFullName().hasNamespace(
+                            handled_module_name
+                        )
+                    )
+                    and source_ref is not None
+                ):
+                    key = (
+                        handled_module_name,
+                        using_module,
+                        source_ref.getLineNumber(),
+                    )
+                    if key not in self.warnings_given:
+                        self.warning(
+                            "Undesirable import of '%s' in '%s' (at '%s') encountered. It may slow down compilation."
+                            % (
+                                handled_module_name,
+                                using_module.getFullName(),
+                                source_ref.getAsString(),
+                            ),
+                            mnemonic="unwanted-module",
+                        )
+
+                        self.warnings_given.add(key)
 
     def onModuleEncounter(self, module_name, module_filename, module_kind):
         for handled_module_name, mode in self.handled_modules.items():
