@@ -1,4 +1,4 @@
-#     Copyright 2022, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -53,9 +53,9 @@ from nuitka.nodes.ExceptionNodes import (
 )
 from nuitka.nodes.FunctionAttributeNodes import ExpressionFunctionErrorStr
 from nuitka.nodes.FunctionNodes import (
-    ExpressionFunctionCall,
-    ExpressionFunctionCreation,
     ExpressionFunctionRef,
+    makeExpressionFunctionCall,
+    makeExpressionFunctionCreation,
 )
 from nuitka.nodes.LoopNodes import StatementLoop, StatementLoopBreak
 from nuitka.nodes.OperatorNodes import makeBinaryOperationNode
@@ -73,7 +73,7 @@ from nuitka.nodes.VariableRefNodes import (
     ExpressionTempVariableRef,
     ExpressionVariableRef,
 )
-from nuitka.nodes.VariableReleaseNodes import makeStatementReleaseVariable
+from nuitka.nodes.VariableReleaseNodes import makeStatementsReleaseVariables
 from nuitka.PythonVersions import (
     getComplexCallSequenceErrorTemplate,
     python_version,
@@ -190,7 +190,7 @@ def getCallableNameDescBody():
     )
 
     if python_version >= 0x390:
-        result.setChild("body", functions_case)
+        result.setChildBody(functions_case)
 
         return result
 
@@ -288,8 +288,7 @@ def getCallableNameDescBody():
     else:
         normal_cases = ("function", "builtin_function_or_method")
 
-    result.setChild(
-        "body",
+    result.setChildBody(
         makeStatementsSequenceFromStatement(
             statement=makeStatementConditional(
                 condition=ExpressionBuiltinIsinstance(
@@ -312,7 +311,7 @@ def getCallableNameDescBody():
                 no_branch=no_branch,
                 source_ref=internal_source_ref,
             )
-        ),
+        )
     )
 
     return result
@@ -332,8 +331,8 @@ def makeStarListArgumentErrorRaise(called_variable, star_list_variable):
                     ),
                     right=makeExpressionMakeTuple(
                         elements=(
-                            ExpressionFunctionCall(
-                                function=ExpressionFunctionCreation(
+                            makeExpressionFunctionCall(
+                                function=makeExpressionFunctionCreation(
                                     function_ref=ExpressionFunctionRef(
                                         function_body=getCallableNameDescBody(),
                                         source_ref=internal_source_ref,
@@ -463,8 +462,8 @@ def _makeRaiseExceptionMustBeMapping(called_variable, star_dict_variable):
                     ),
                     right=makeExpressionMakeTuple(
                         elements=(
-                            ExpressionFunctionCall(
-                                function=ExpressionFunctionCreation(
+                            makeExpressionFunctionCall(
+                                function=makeExpressionFunctionCreation(
                                     function_ref=ExpressionFunctionRef(
                                         function_body=getCallableNameDescBody(),
                                         source_ref=internal_source_ref,
@@ -650,23 +649,19 @@ def _makeStarDictArgumentToDictStatement(result, called_variable, star_dict_vari
         source_ref=internal_source_ref,
     )
 
-    final = (
-        makeStatementReleaseVariable(
-            variable=tmp_dict_variable, source_ref=internal_source_ref
-        ),
-        makeStatementReleaseVariable(
-            variable=tmp_iter_variable, source_ref=internal_source_ref
-        ),
-        makeStatementReleaseVariable(
-            variable=tmp_keys_variable, source_ref=internal_source_ref
-        ),
-        makeStatementReleaseVariable(
-            variable=tmp_key_variable, source_ref=internal_source_ref
-        ),
-    )
-
     return makeTryFinallyStatement(
-        provider=result, tried=tried, final=final, source_ref=internal_source_ref
+        provider=result,
+        tried=tried,
+        final=makeStatementsReleaseVariables(
+            variables=(
+                tmp_dict_variable,
+                tmp_iter_variable,
+                tmp_keys_variable,
+                tmp_key_variable,
+            ),
+            source_ref=internal_source_ref,
+        ),
+        source_ref=internal_source_ref,
     )
 
 
@@ -679,8 +674,8 @@ def _makeRaiseNoStringItem(called_variable):
                 source_ref=internal_source_ref,
                 user_provided=True,
             ),
-            right=ExpressionFunctionCall(
-                function=ExpressionFunctionCreation(
+            right=makeExpressionFunctionCall(
+                function=makeExpressionFunctionCreation(
                     function_ref=ExpressionFunctionRef(
                         function_body=getCallableNameDescBody(),
                         source_ref=internal_source_ref,
@@ -734,8 +729,8 @@ def _makeRaiseDuplicationItem(called_variable, tmp_key_variable):
                     ),
                     right=makeExpressionMakeTuple(
                         elements=(
-                            ExpressionFunctionCall(
-                                function=ExpressionFunctionCreation(
+                            makeExpressionFunctionCall(
+                                function=makeExpressionFunctionCreation(
                                     function_ref=ExpressionFunctionRef(
                                         function_body=getCallableNameDescBody(),
                                         source_ref=internal_source_ref,
@@ -782,18 +777,7 @@ def _makeStarDictArgumentMergeToKwStatement(
     tmp_keys_variable = result.allocateTempVariable(temp_scope, "keys")
     tmp_key_variable = result.allocateTempVariable(temp_scope, "key_xxx")
 
-    final = [
-        makeStatementReleaseVariable(
-            variable=tmp_iter_variable, source_ref=internal_source_ref
-        ),
-        makeStatementReleaseVariable(
-            variable=tmp_keys_variable, source_ref=internal_source_ref
-        ),
-        makeStatementReleaseVariable(
-            variable=tmp_key_variable, source_ref=internal_source_ref
-        ),
-    ]
-
+    tmp_variables = [tmp_iter_variable, tmp_keys_variable, tmp_key_variable]
     mapping_loop_body = (
         makeStatementConditional(
             condition=ExpressionComparisonIn(
@@ -875,18 +859,7 @@ def _makeStarDictArgumentMergeToKwStatement(
     tmp_item_variable = result.allocateTempVariable(temp_scope, "item")
     tmp_key_variable = result.allocateTempVariable(temp_scope, "key")
 
-    final += (
-        makeStatementReleaseVariable(
-            variable=tmp_iter_variable, source_ref=internal_source_ref
-        ),
-        makeStatementReleaseVariable(
-            variable=tmp_item_variable, source_ref=internal_source_ref
-        ),
-        makeStatementReleaseVariable(
-            variable=tmp_key_variable, source_ref=internal_source_ref
-        ),
-    )
-
+    tmp_variables += [tmp_iter_variable, tmp_item_variable, tmp_key_variable]
     dict_loop_body = (
         makeStatementAssignmentVariable(
             variable=tmp_key_variable,
@@ -997,7 +970,13 @@ def _makeStarDictArgumentMergeToKwStatement(
     )
 
     return makeTryFinallyStatement(
-        provider=result, tried=tried, final=final, source_ref=internal_source_ref
+        provider=result,
+        tried=tried,
+        final=makeStatementsReleaseVariables(
+            variables=tmp_variables,
+            source_ref=internal_source_ref,
+        ),
+        source_ref=internal_source_ref,
     )
 
 
@@ -1059,7 +1038,7 @@ def getFunctionCallHelperStarList():
         ),
     )
 
-    result.setChild("body", body)
+    result.setChildBody(body)
 
     return result
 
@@ -1128,7 +1107,7 @@ def getFunctionCallHelperKeywordsStarList():
         ),
     )
 
-    result.setChild("body", body)
+    result.setChildBody(body)
 
     return result
 
@@ -1202,7 +1181,7 @@ def getFunctionCallHelperPosStarList():
         ),
     )
 
-    result.setChild("body", body)
+    result.setChildBody(body)
 
     return result
 
@@ -1279,7 +1258,7 @@ def getFunctionCallHelperPosKeywordsStarList():
         ),
     )
 
-    result.setChild("body", body)
+    result.setChildBody(body)
 
     return result
 
@@ -1358,7 +1337,7 @@ def getFunctionCallHelperStarDict():
         ),
     )
 
-    result.setChild("body", body)
+    result.setChildBody(body)
 
     return result
 
@@ -1442,7 +1421,7 @@ def getFunctionCallHelperPosStarDict():
         ),
     )
 
-    result.setChild("body", body)
+    result.setChildBody(body)
 
     return result
 
@@ -1550,7 +1529,7 @@ def getFunctionCallHelperKeywordsStarDict():
         ),
     )
 
-    result.setChild("body", body)
+    result.setChildBody(body)
 
     return result
 
@@ -1662,7 +1641,7 @@ def getFunctionCallHelperPosKeywordsStarDict():
         ),
     )
 
-    result.setChild("body", body)
+    result.setChildBody(body)
 
     return result
 
@@ -1757,7 +1736,7 @@ def getFunctionCallHelperStarListStarDict():
 
     body = makeStatementsSequenceFromStatements(*statements)
 
-    result.setChild("body", body)
+    result.setChildBody(body)
 
     return result
 
@@ -1831,7 +1810,7 @@ def getFunctionCallHelperPosStarListStarDict():
 
     body = makeStatementsSequenceFromStatements(*statements)
 
-    result.setChild("body", body)
+    result.setChildBody(body)
 
     return result
 
@@ -1895,7 +1874,7 @@ def getFunctionCallHelperKeywordsStarListStarDict():
 
     body = makeStatementsSequenceFromStatements(*statements)
 
-    result.setChild("body", body)
+    result.setChildBody(body)
 
     return result
 
@@ -1973,7 +1952,7 @@ def getFunctionCallHelperPosKeywordsStarListStarDict():
 
     body = makeStatementsSequenceFromStatements(*statements)
 
-    result.setChild("body", body)
+    result.setChildBody(body)
 
     return result
 
@@ -2094,24 +2073,6 @@ def getFunctionCallHelperDictionaryUnpacking():
         ),
     )
 
-    final = (
-        makeStatementReleaseVariable(
-            variable=tmp_result_variable, source_ref=internal_source_ref
-        ),
-        makeStatementReleaseVariable(
-            variable=tmp_iter_variable, source_ref=internal_source_ref
-        ),
-        makeStatementReleaseVariable(
-            variable=tmp_item_variable, source_ref=internal_source_ref
-        ),
-        makeStatementReleaseVariable(
-            variable=tmp_iter2_variable, source_ref=internal_source_ref
-        ),
-        makeStatementReleaseVariable(
-            variable=tmp_key_variable, source_ref=internal_source_ref
-        ),
-    )
-
     tried = makeStatementsSequenceFromStatements(
         makeStatementAssignmentVariable(
             variable=tmp_iter_variable,
@@ -2145,11 +2106,20 @@ def getFunctionCallHelperDictionaryUnpacking():
         makeTryFinallyStatement(
             provider=result,
             tried=tried,
-            final=final,
+            final=makeStatementsReleaseVariables(
+                variables=(
+                    tmp_result_variable,
+                    tmp_iter_variable,
+                    tmp_item_variable,
+                    tmp_iter2_variable,
+                    tmp_key_variable,
+                ),
+                source_ref=internal_source_ref,
+            ),
             source_ref=internal_source_ref,
         )
     )
 
-    result.setChild("body", body)
+    result.setChildBody(body)
 
     return result
