@@ -1,4 +1,4 @@
-#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -28,8 +28,8 @@ merely helpers to do it.
 
 from nuitka.ModuleRegistry import getRootTopModule
 from nuitka.nodes.FunctionNodes import (
-    ExpressionFunctionBody,
     ExpressionFunctionPureBody,
+    ExpressionFunctionPureInlineConstBody,
 )
 from nuitka.SourceCodeReferences import fromFilename
 
@@ -66,11 +66,11 @@ def getInternalModule():
 
 def makeInternalHelperFunctionBody(name, parameters, inline_const_args=False):
     if inline_const_args:
-        node_class = ExpressionFunctionPureBody
+        node_class = ExpressionFunctionPureInlineConstBody
     else:
-        node_class = ExpressionFunctionBody
+        node_class = ExpressionFunctionPureBody
 
-    return node_class(
+    result = node_class(
         provider=getInternalModule(),
         name=name,
         code_object=None,
@@ -80,3 +80,8 @@ def makeInternalHelperFunctionBody(name, parameters, inline_const_args=False):
         auto_release=None,
         source_ref=internal_source_ref,
     )
+
+    for variable in parameters.getAllVariables():
+        result.removeVariableReleases(variable)
+
+    return result
