@@ -1,4 +1,4 @@
-#     Copyright 2022, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -22,9 +22,6 @@ You can visit a scope, a tree (module), or every scope of a tree (module).
 
 """
 
-from nuitka.containers.OrderedSets import OrderedSet
-from nuitka.Tracing import general
-
 
 def visitTree(tree, visitor):
     visitor.onEnterNode(tree)
@@ -44,25 +41,3 @@ class VisitorNoopMixin(object):
 
     def onLeaveNode(self, node):
         """Overloaded for operation after the node children were done."""
-
-
-class DetectUsedModules(VisitorNoopMixin):
-    def __init__(self):
-        self.used_modules = OrderedSet()
-
-    def onEnterNode(self, node):
-        try:
-            self._onEnterNode(node)
-        except Exception:
-            general.my_print(
-                "Problem with %r at %s"
-                % (node, node.getSourceReference().getAsString())
-            )
-            raise
-
-    def _onEnterNode(self, node):
-        if node.isExpression():
-            self.used_modules.update(node.getUsedModules())
-
-    def getUsedModules(self):
-        return self.used_modules
