@@ -1,4 +1,4 @@
-#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -17,17 +17,13 @@
 #
 """ Reformulation of try/finally statements.
 
-Consult the developer manual for information. TODO: Add ability to sync
-source code comments with developer manual sections.
+Consult the Developer Manual for information. TODO: Add ability to sync
+source code comments with Developer Manual sections.
 
 """
 
-from nuitka import Options
 from nuitka.nodes.LoopNodes import StatementLoopBreak, StatementLoopContinue
-from nuitka.nodes.ReturnNodes import (
-    ExpressionReturnedValueRef,
-    StatementReturn,
-)
+from nuitka.nodes.ReturnNodes import StatementReturnReturnedValue
 from nuitka.nodes.StatementNodes import (
     StatementPreserveFrameException,
     StatementPublishException,
@@ -104,11 +100,6 @@ def makeTryFinallyStatement(provider, tried, final, source_ref, public_exc=False
         tried.parent = provider
         final.parent = provider
 
-    # TODO: Currently it's not possible anymore to get at XML for all codes
-    # during the building phase. So this error catcher cannot work currently.
-    if False and Options.is_debug:
-        _checkCloning(final, provider)
-
     def getFinal():
         # Make a clone of "final" only if necessary.
         if hasattr(getFinal, "used"):
@@ -171,8 +162,7 @@ def makeTryFinallyStatement(provider, tried, final, source_ref, public_exc=False
     if tried.mayReturn():
         return_handler = getStatementsAppended(
             statement_sequence=getFinal(),
-            statements=StatementReturn(
-                expression=ExpressionReturnedValueRef(source_ref=source_ref),
+            statements=StatementReturnReturnedValue(
                 source_ref=source_ref,
             ),
         )
@@ -198,7 +188,7 @@ def makeTryFinallyStatement(provider, tried, final, source_ref, public_exc=False
 
 def buildTryFinallyNode(provider, build_tried, node, source_ref):
 
-    if python_version < 300:
+    if python_version < 0x300:
         # Prevent "continue" statements in the final blocks
         pushBuildContext("finally")
         final = buildStatementsNode(
@@ -207,7 +197,11 @@ def buildTryFinallyNode(provider, build_tried, node, source_ref):
         popBuildContext()
 
         return makeTryFinallyStatement(
-            provider=provider, tried=build_tried(), final=final, source_ref=source_ref
+            provider=provider,
+            tried=build_tried(),
+            final=final,
+            source_ref=source_ref,
+            public_exc=False,
         )
     else:
         tried = build_tried()
