@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-#     Copyright 2021, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2023, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python tests originally created or extracted from other peoples work. The
 #     parts were too small to be protected.
@@ -62,7 +62,12 @@ def main():
         active = search_mode.consider(dirname=None, filename=filename)
 
         if active:
-            extra_flags = ["expect_failure", "remove_output", "syntax_errors"]
+            extra_flags = [
+                "expect_failure",
+                "remove_output",
+                "syntax_errors",
+                "--nofollow-imports",
+            ]
 
             compareWithCPython(
                 dirname=None,
